@@ -139,6 +139,12 @@ class ContentRating(Enum):
         content was also the type of content that old MangaDex APIs used to call "hentai".
     """
 
+    NO_RATING = "none"
+    """A manga that has no content rating.
+    
+    .. versionadded:: 1.0
+    """
+
 
 class Visibility(Enum):
     """An enum representing the visibility of an :class:`.CustomList`. Source:
@@ -185,6 +191,12 @@ class Relationship(Enum):
     CUSTOM_LIST = "custom_list"
     """A :class:`.CustomList` resource."""
 
+    COVER_ART = "cover_art"
+    """A :class:`.CoverArt` resource.
+    
+    .. versionadded:: 1.0
+    """
+
 
 class DuplicateResolutionAlgorithm(Enum):
     """An enum representing the various methods of resolving duplicate chapters in the same language.
